pub struct SystemTimeError(Duration);Expand description
An error returned from the duration_since and elapsed methods on
SystemTime, used to learn how far in the opposite direction a system time
lies.
Examples
Tuple Fields
0: DurationImplementations
Sourceimpl SystemTimeError
impl SystemTimeError
1.8.0 · Sourcepub fn duration(&self) -> Duration
pub fn duration(&self) -> Duration
Returns the positive duration which represents how far forward the second system time was from the first.
A SystemTimeError is returned from the SystemTime::duration_since
and SystemTime::elapsed methods whenever the second system time
represents a point later in time than the self of the method call.
Examples